Name:		bolt
Version:	0.9.5
Release:	%mkrel 1
Summary:	Thunderbolt device manager
Group:		System/Kernel and hardware
License:	LGPLv2+
URL:		https://gitlab.freedesktop.org/bolt/bolt
Source0:	https://gitlab.freedesktop.org/bolt/bolt/-/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:	gcc
BuildRequires:	asciidoc
BuildRequires:	meson
BuildRequires:	pkgconfig(gio-2.0)
BuildRequires:	pkgconfig(libudev)
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	pkgconfig(polkit-agent-1)
BuildRequires:	systemd

# for the integration test (optional)
BuildRequires:	pkgconfig(pygobject-3.0)
BuildRequires:	pkgconfig(umockdev-1.0)
BuildRequires:	python3-dbus
BuildRequires:	python3-dbusmock

Requires(post):		rpm-helper >= %{rpmhelper_required_version}
Requires(preun):	rpm-helper >= %{rpmhelper_required_version}

%description
bolt is a system daemon to manage thunderbolt 3 devices via a D-BUS
API.  Thunderbolt 3 features different security modes that require
devices to be authorized before they can be used. The D-Bus API can be
used to list devices, enroll them (authorize and store them in the
local database) and forget them again (remove previously enrolled
devices). It also emits signals if new devices are connected (or
removed). During enrollment devices can be set to be automatically
authorized as soon as they are connected.  A command line tool, called
boltctl, can be used to control the daemon and perform all the above
mentioned tasks.

%prep
%autosetup -p1

%build
%meson -Ddb-name=boltd
%meson_build

%check
%meson_test

%install
%meson_install

%post
%_post_service %{name}

%preun
%_preun_service %{name}

%files
%license COPYING
%doc README.md
%{_bindir}/boltctl
%{_libexecdir}/boltd
%{_unitdir}/%{name}.service
%{_udevrulesdir}/*-%{name}.rules
%{_datadir}/dbus-1/system.d/org.freedesktop.bolt.conf
%{_datadir}/dbus-1/interfaces/org.freedesktop.bolt.xml
%{_datadir}/polkit-1/actions/org.freedesktop.bolt.policy
%{_datadir}/polkit-1/rules.d/org.freedesktop.bolt.rules
%{_datadir}/dbus-1/system-services/org.freedesktop.bolt.service
%{_mandir}/man1/boltctl.1*
%{_mandir}/man8/boltd.8*
%ghost %dir %{_localstatedir}/lib/boltd


%changelog
* Sun Jan 08 2023 daviddavid <daviddavid> 0.9.5-1.mga9
+ Revision: 1931379
- new version: 0.9.5

* Thu Nov 10 2022 daviddavid <daviddavid> 0.9.4-1.mga9
+ Revision: 1905046
- new version: 0.9.4

* Tue Sep 27 2022 papoteur <papoteur> 0.9.3-1.mga9
+ Revision: 1892613
- new 0.9.3

* Sat Sep 10 2022 neoclust <neoclust> 0.9.2-1.mga9
+ Revision: 1886618
- New version 0.9.2

* Sat Apr 02 2022 umeabot <umeabot> 0.9.1-2.mga9
+ Revision: 1841095
- Mageia 9 Mass Rebuild

* Fri Dec 04 2020 daviddavid <daviddavid> 0.9.1-1.mga8
+ Revision: 1652417
- new version: 0.9.1

* Wed Jun 17 2020 daviddavid <daviddavid> 0.9-1.mga8
+ Revision: 1593973
- new version: 0.9
- remove merged upstream patches

* Wed Feb 19 2020 umeabot <umeabot> 0.8-3.mga8
+ Revision: 1544133
- Mageia 8 Mass Rebuild

* Fri Jan 24 2020 daviddavid <daviddavid> 0.8-2.mga8
+ Revision: 1482598
- add patch to ignore uevents from wakeup devices. See upstream issue
  https://gitlab.freedesktop.org/bolt/bolt/issues/156
- add patch to fix BoltError not being a typedef

* Sun Jun 30 2019 daviddavid <daviddavid> 0.8-1.mga8
+ Revision: 1416240
- new version: 0.8

* Wed Apr 17 2019 umeabot <umeabot> 0.7-2.mga7
+ Revision: 1392126
- Rebuild with meson 0.50.1

* Fri Jan 04 2019 daviddavid <daviddavid> 0.7-1.mga7
+ Revision: 1349001
- new version: 0.7

* Thu Nov 29 2018 daviddavid <daviddavid> 0.6-2.mga7
+ Revision: 1336650
- rebuild with fixed umockdev gir stuff

* Thu Nov 29 2018 daviddavid <daviddavid> 0.6-1.mga7
+ Revision: 1336639
- initial package bolt (mga#23917)

